
/**********************************************************************************
 Persistence of Vision Ray Tracer Scene Description File
 File name   : Eval_pigment_mcr.inc
 Version     : 3.7
 Description : A collection of macros using the eval_pigment() function, for placing
               objects on a surface according to the color value of the provided
               image_map.
               
               For large amounts of objects, it is better to copy the macro
               to the scene file for increased parsing speed.
               
               The following image_maps are available:
               - SpottedColor2x.png
               - SpottedColor2x_tile.png (tileable map)
               - SpottedColor3x.png
               - SpottedColor3x_tile.png (tileable map)
               
 Date        : April 2005 / February 2014
 Author      : Thomas A. M. de Groot
 E-mail      : thomdegdot01atgmaildotcom
 
 This file is licensed under the terms of the CC-LGPL
 Copyright (C) 2005/2014. All rights reserved.
**********************************************************************************/

// Macro using the 2 colours image_map SpottedColor2x.png or SpottedColor2x_tile.png :
#macro EvalPig2x(Map,Pos,Object1, Object2,MinScale,MaxScale,MinRot,MaxRot,Seed)
  #local Shade = eval_pigment(Map,<Pos.x,0,Pos.z>);
  #if (Shade.red  = 255/255)
    object {
      Object1
      scale RRand(MinScale, MaxScale, Seed)
      rotate RRand(MinRot, MaxRot, Seed)*y
      translate Pos
    }
  #else
    object {
      Object2
      scale RRand(MinScale, MaxScale, Seed)
      rotate RRand(MinRot, MaxRot, Seed)*y
      translate Pos
    }
  #end  //of eval_pigment
#end  //of macro


// Macro using the 3 colours image_map SpottedColor3x.png or SpottedColor3x_tile.png :
#macro EvalPig3x(Map,Pos,Object1, Object2,Object3,MinScale,MaxScale,MinRot,MaxRot,Seed)
  #local Shade = eval_pigment(Map,<Pos.x,0,Pos.z>);
  #if (Shade.red  = 255/255)
    object {
      Object1
      scale RRand(MinScale, MaxScale, Seed)
      rotate RRand(MinRot, MaxRot, Seed)*y
      Reorient_Trans(y, Norm)
      translate Pos
    }
  #end
  #if (Shade.green = 255/255)
    object {
      Object2
      scale RRand(MinScale, MaxScale, Seed)
      rotate RRand(MinRot, MaxRot, Seed)*y
      Reorient_Trans(y, Norm)
      translate Pos
    }
  #end
  #if (Shade.blue = 255/255)
    object {
      Object3
      scale RRand(MinScale, MaxScale, Seed)
      rotate RRand(MinRot, MaxRot, Seed)*y
      Reorient_Trans(y, Norm)
      translate Pos
    }
  #end
#end  //of macro


// Macro using all the colours of an image_map :
#macro EvalPigAll(Map,Pos,Object,Seed)
  #declare Shade = eval_pigment(Map,<Pos.x,0,Pos.z>);
  object {Object
    pigment {rgb <Shade.x,Shade.y,Shade.z>}
    scale <1, RRand(0.95, 1.05, Seed), 1>
    Reorient_Trans(y,Norm)
    translate Pos
  }
#end  //of macro

